"""Unit test package for unfccc_di_api.

Code coverage metrics:

.. image:: https://codecov.io/gh/pik-primap/unfccc_di_api/branch/main/graph/badge.svg?token=OI2MYECSVO  # noqa: E501
        :target: https://codecov.io/gh/pik-primap/unfccc_di_api
        :alt: Coverage metrics

"""
